/* Do not edit this file, make creates it. */
#ifndef _h_tc_const
#define _h_tc_const
extern Char STR0[];
extern Char STR1[];
extern Char STRBB[];
extern Char STRCLICOLOR_FORCE[];
extern Char STRCOLUMNS[];
extern Char STRCOMMAND_LINE[];
extern Char STRDING[];
extern Char STREnhance[];
extern Char STRHOSTTYPE[];
extern Char STRHOST[];
extern Char STRKCORRECT[];
extern Char STRKGROUP[];
extern Char STRKHOME[];
extern Char STRKPATH[];
extern Char STRKSHLVL[];
extern Char STRKTERM[];
extern Char STRKUSER[];
extern Char STRLANG[];
extern Char STRLC_ALL[];
extern Char STRLC_COLLATE[];
extern Char STRLC_CTYPE[];
extern Char STRLC_MESSAGES[];
extern Char STRLC_MONETARY[];
extern Char STRLC_NUMERIC[];
extern Char STRLC_TIME[];
extern Char STRLINES[];
extern Char STRLOGNAME[];
extern Char STRLSCOLORS[];
extern Char STRLS_COLORS[];
extern Char STRLbrace[];
extern Char STRLparen[];
extern Char STRLparensp[];
extern Char STRMACHTYPE[];
extern Char STRNLSPATH[];
extern Char STRNOREBIND[];
extern Char STRNULL[];
extern Char STROSTYPE[];
extern Char STRPWD[];
extern Char STRQNULL[];
extern Char STRQQ[];
extern Char STRREMOTEHOST[];
extern Char STRRbrace[];
extern Char STRRparen[];
extern Char STRTERMCAP[];
extern Char STRVENDOR[];
extern Char STR_[];
extern Char STRaddsuffix[];
extern Char STRalias[];
extern Char STRall[];
extern Char STRalways[];
extern Char STRambiguous[];
extern Char STRampm[];
extern Char STRand2[];
extern Char STRand[];
extern Char STRany[];
extern Char STRanyerror[];
extern Char STRaout[];
extern Char STRargv[];
extern Char STRask[];
extern Char STRautocorrect[];
extern Char STRautoexpand[];
extern Char STRautolist[];
extern Char STRautologout[];
extern Char STRautomatic[];
extern Char STRautorehash[];
extern Char STRbackqpwd[];
extern Char STRbackslash_quote[];
extern Char STRbang[];
extern Char STRbeepcmd[];
extern Char STRboth[];
extern Char STRbsd[];
extern Char STRcaret[];
extern Char STRcatalog[];
extern Char STRcd[];
extern Char STRcdpath[];
extern Char STRcdtohome[];
extern Char STRcent2[];
extern Char STRcenthash[];
extern Char STRcentminus[];
extern Char STRcentplus[];
extern Char STRchase[];
extern Char STRcmd[];
extern Char STRco[];
extern Char STRcolon[];
extern Char STRcolor[];
extern Char STRcommand[];
extern Char STRcompat_expr[];
extern Char STRcomplete[];
extern Char STRcontinue[];
extern Char STRcontinue_args[];
extern Char STRcorrect[];
extern Char STRcsubstnonl[];
extern Char STRcwd[];
extern Char STRcwdcmd[];
extern Char STRdefault[];
extern Char STRdefautologout[];
extern Char STRdefprompt[];
extern Char STRdextract[];
extern Char STRdirsfile[];
extern Char STRdirstack[];
extern Char STRdot[];
extern Char STRdotdotsl[];
extern Char STRdotsl[];
extern Char STRdown[];
extern Char STRdumb[];
extern Char STRdunique[];
extern Char STRecho[];
extern Char STRecho_style[];
extern Char STRedit[];
extern Char STReditors[];
extern Char STRellipsis[];
extern Char STRend[];
extern Char STRenhance[];
extern Char STReof[];
extern Char STRequal[];
extern Char STRerase[];
extern Char STReuid[];
extern Char STReuser[];
extern Char STRexpand[];
extern Char STRfakecom1[];
extern Char STRfakecom[];
extern Char STRfignore[];
extern Char STRfilec[];
extern Char STRgid[];
extern Char STRglobdot[];
extern Char STRglobstar[];
extern Char STRgroup[];
extern Char STRgt[];
extern Char STRhangup[];
extern Char STRhelpcommand[];
extern Char STRhighlight[];
extern Char STRhistchars[];
extern Char STRhistdup[];
extern Char STRhistfile[];
extern Char STRhistlit[];
extern Char STRhistory[];
extern Char STRhome[];
extern Char STRhup[];
extern Char STRigncase[];
extern Char STRignore[];
extern Char STRignoreeof[];
extern Char STRimplicitcd[];
extern Char STRinputmode[];
extern Char STRinsert[];
extern Char STRjobcmd[];
extern Char STRjobs[];
extern Char STRkilldup[];
extern Char STRkillring[];
extern Char STRleft[];
extern Char STRli[];
extern Char STRlistflags[];
extern Char STRlistjobs[];
extern Char STRlistlinks[];
extern Char STRlistmax[];
extern Char STRlistmaxrows[];
extern Char STRlock[];
extern Char STRloginsh[];
extern Char STRlogout[];
extern Char STRlong[];
extern Char STRls[];
extern Char STRlsmF[];
extern Char STRmCF[];
extern Char STRmZ[];
extern Char STRmail[];
extern Char STRmatchbeep[];
extern Char STRmaxint[];
extern Char STRmerge[];
extern Char STRmf[];
extern Char STRmhT[];
extern Char STRmh[];
extern Char STRminus1[];
extern Char STRminus[];
extern Char STRml[];
extern Char STRmm[];
extern Char STRmmcolormalways[];
extern Char STRmmcolormauto[];
extern Char STRmn[];
extern Char STRmquestion[];
extern Char STRmr[];
extern Char STRnetwork[];
extern Char STRnice[];
extern Char STRnoambiguous[];
extern Char STRnobeep[];
extern Char STRnoclobber[];
extern Char STRnoding[];
extern Char STRnoglob[];
extern Char STRnohup[];
extern Char STRnokanji[];
extern Char STRnomatch[];
extern Char STRnone[];
extern Char STRnonomatch[];
extern Char STRnormal[];
extern Char STRnostat[];
extern Char STRnotempty[];
extern Char STRnotify[];
extern Char STRnotunique[];
extern Char STRonlyhistory[];
extern Char STRor2[];
extern Char STRor[];
extern Char STRoverwrite[];
extern Char STRowd[];
extern Char STRpadhour[];
extern Char STRparseoctal[];
extern Char STRpath[];
extern Char STRperiodic[];
extern Char STRpostcmd[];
extern Char STRprecmd[];
extern Char STRprev[];
extern Char STRprintexitvalue[];
extern Char STRprompt2[];
extern Char STRprompt3[];
extern Char STRprompt[];
extern Char STRpromptchars[];
extern Char STRptssl[];
extern Char STRpushdsilent[];
extern Char STRpushdtohome[];
extern Char STRrecexact[];
extern Char STRrecognize_only_executables[];
extern Char STRrepeat[];
extern Char STRret[];
extern Char STRright[];
extern Char STRrm[];
extern Char STRrmstar[];
extern Char STRrprompt[];
extern Char STRsavedirs[];
extern Char STRsavehist[];
extern Char STRsched[];
extern Char STRsemi[];
extern Char STRsemisp[];
extern Char STRshell[];
extern Char STRshlvl[];
extern Char STRshwordsep[];
extern Char STRshwspace[];
extern Char STRslash[];
extern Char STRsldotcshrc[];
extern Char STRsldotlogin[];
extern Char STRsldottcshrc[];
extern Char STRsldtlogout[];
extern Char STRsource[];
extern Char STRspLarrow2sp[];
extern Char STRspLarrowsp[];
extern Char STRspRarrow2[];
extern Char STRspRarrow[];
extern Char STRspRparen[];
extern Char STRspace[];
extern Char STRspand2sp[];
extern Char STRspor2sp[];
extern Char STRsporsp[];
extern Char STRstar[];
extern Char STRstatus[];
extern Char STRsymlinks[];
extern Char STRsysv[];
extern Char STRtcsh[];
extern Char STRterm[];
extern Char STRthen[];
extern Char STRtilde[];
extern Char STRtildotdirs[];
extern Char STRtildothist[];
extern Char STRtime[];
extern Char STRtmpsh[];
extern Char STRtperiod[];
extern Char STRtty[];
extern Char STRuid[];
extern Char STRunalias[];
extern Char STRunderpause[];
extern Char STRunknown[];
extern Char STRup[];
extern Char STRuser[];
extern Char STRverbose[];
extern Char STRversion[];
extern Char STRvimode[];
extern Char STRvisiblebell[];
extern Char STRwatch[];
extern Char STRwho[];
extern Char STRwordchars[];
#endif /* _h_tc_const */
